package com.dsic.gj_erp.pc.dto.data;

import cn.hutool.core.bean.BeanUtil;
import com.alibaba.fastjson.JSONObject;
import com.dsic.gj_erp.bean.jcsj.DmBom;
import com.dsic.gj_erp.pc.Constant;
import com.dsic.gj_erp.pc.dto.设备;
import com.dsic.gj_erp.pc.dto.资源;
import lombok.Getter;
import lombok.Setter;

import java.util.ArrayList;
import java.util.Arrays;
import java.util.List;
import java.util.Map;

@Getter
@Setter
public class Bom {
    private String dcch;
    private String mbch;
    private String pl;
    private String _pl;//曲外板pl需要增加Q,这里
    private String fd;

    private String xzglxq;
    private String dzglxq;

    private String zl;
    private String kw;
    private String tzbh;
    private String wpgg;
    private String wpcz;
    private String ljsl;
    private Map<String,String> degs;
    private 设备 所在设备;
    private 资源 所在资源;
    private List<Constant.工序> 已排工序;
    private List<ErrorType> errors;

    public static Bom of(String xzxq, String dzxq, DmBom bom){
        Bom _bom = new Bom();
        BeanUtil.copyProperties(bom,_bom);
        _bom.xzglxq=xzxq;
        _bom.dzglxq=dzxq;
        _bom.已排工序 =new ArrayList<>();
        _bom.errors=new ArrayList<>();
        return _bom;
    }

    public boolean 判断是否为可识别跨位和切割设备的套料图(){
        String[] 切割设备可加工套料图分类码= {
                "N1AX","N1AD","N1LD","N2BX","N2BD","N2CX","N2CD","N2HX","N2HD","S2TX","S2TD","N3CX","N3CD",
                "S3PX","S3PD","S3XX","N4PX","N4PD","N4XX","N2TX","N2TD"
        };
        return Arrays.stream(切割设备可加工套料图分类码).anyMatch(it->it.equals(this.获取套料图分类码()));
    }

    public String 获取套料图分类码(){
        return this.tzbh.substring(4,8).toUpperCase();
    }

    public double 根据工序获取产能需求量(Constant.工序 _工序){
        switch (_工序) {
            case 上料:
                return 1;
            case 抛丸:
                return 1;
            case 理料:
                return 1;
            case 划线:
                return 1;
            case 切割:
                return 1;
            case 坡口:
                return 1;
            case 型材面板:
                return 1;
            case 曲型:
                return 1;
            case 打磨:
                return 1;
            case 自由边处理:
                return 1;
            case 光电结束:
                return 1;
//            case 预配盘:
//                return new 工序01上料(_工序,_设备);
//            case 配送:
//                return new 工序01上料(_工序,_设备);
            default:
                return 0;
        }
    }

    public String toString() {
        return JSONObject.toJSONString(this);
    }

    public void 坡口结束日期不满足大组需求期(){
        this.errors.add(ErrorType.坡口结束日期不满足大组需求期);
    }

    public void 没有订货(){
        this.errors.add(ErrorType.没有订货);
    }

    public void 订货计划到齐日期格式错误(){
        this.errors.add(ErrorType.订货计划到齐日期格式错误);
    }
    public void 上料之前无法到货(){
        this.errors.add(ErrorType.上料之前无法到货);
        this.errors.add(ErrorType.需求日期按照中日程计算);
    }

    public void 缺少中日程(){
        this.errors.add(ErrorType.缺少中日程);
        this.errors.add(ErrorType.按照中日程计划上料日期失败);
    }

    public void 中日期无小组需求期(){
        this.errors.add(ErrorType.中日期无小组需求期);
        this.errors.add(ErrorType.按照中日程计划上料日期失败);
    }

    public void 中日程无大组需求期(){
        this.errors.add(ErrorType.中日程无大组需求期);
        this.errors.add(ErrorType.按照中日程计划上料日期失败);
    }

    public void 缺少大组需求期使用小组需求替代(){
        this.errors.add(ErrorType.缺少大组需求期使用小组需求替代);
    }

    public void 超出工序产能(Constant.工序 _工序){
        switch (_工序) {
            case 上料:
                this.errors.add(ErrorType.超出上料工序产能);
                break;
            case 抛丸:
                this.errors.add(ErrorType.超出抛丸工序产能);
                break;
            case 理料:
                this.errors.add(ErrorType.超出理料工序产能);
                break;
            case 划线:
                this.errors.add(ErrorType.超出划线工序产能);
                break;
            case 切割:
                this.errors.add(ErrorType.超出切割工序产能);
                break;
            case 坡口:
                this.errors.add(ErrorType.超出坡口工序产能);
                break;
            case 型材面板:
                this.errors.add(ErrorType.超出型材面板工序产能);
                break;
            case 曲型:
                this.errors.add(ErrorType.超出曲加工工序产能);
                break;
            case 打磨:
                this.errors.add(ErrorType.超出打磨工序产能);
                break;
            case 自由边处理:
                this.errors.add(ErrorType.超出自由边处理工序产能);
                break;
            case 光电结束:
                this.errors.add(ErrorType.超出光电工序产能);
                break;
        }
    }

    private enum ErrorType{
        缺少大组需求期使用小组需求替代,
        缺少中日程,
        中日期无小组需求期,
        中日程无大组需求期,
        按照中日程计划上料日期失败,
        坡口结束日期不满足大组需求期,
        没有订货,
        订货计划到齐日期格式错误,
        上料之前无法到货,
        需求日期按照中日程计算,
        超出上料工序产能,
        超出抛丸工序产能,
        超出理料工序产能,
        超出划线工序产能,
        超出切割工序产能,
        超出打磨工序产能,
        超出坡口工序产能,
        超出型材面板工序产能,
        超出曲加工工序产能,
        超出自由边处理工序产能,
        超出光电工序产能
    }
}
