package com.dsic.gj_erp.service.sy.impl;


import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.dsic.gj_erp.bean.ResultBean;
import com.dsic.gj_erp.bean.sy.DmEmployee;
import com.dsic.gj_erp.mapper.DmEmployeeMapper;
import com.dsic.gj_erp.service.sy.DmEmployeeService;
import com.dsic.gj_erp.util.ConditionSelect;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import javax.annotation.Resource;
import java.util.List;

/**
 * @version V1.0.0
 * @Title: DmEmployeeServiceImpl
 * @Package com.dsic.xzerp.service.sy.impl
 * @Description: 管系制造员工service实现类
 * @author: 张恩铭
 * @date: 2021/4/2 9:05
 */
@Service
public class DmEmployeeServiceImpl extends ServiceImpl<DmEmployeeMapper, DmEmployee> implements DmEmployeeService {

    @Resource
    private DmEmployeeMapper dmEmployeeMapper;

    private ResultBean resultBean;

    /**
     * 查询所有
     * @return
     */
    @Override
    public List<DmEmployee> getAll() {
        return this.dmEmployeeMapper.selectList(null);
    }

    /**
     * 非like不定条件查询
     * @param dmEmployee
     * @return
     */
    @Override
    public List<DmEmployee> getByCondition(DmEmployee dmEmployee) {
        ConditionSelect<DmEmployee> conditionSelect = new ConditionSelect<>(dmEmployee, new QueryWrapper<>(), this.dmEmployeeMapper);
        return conditionSelect.getResult();
    }

    /**
     * 特定like不定条件查询
     * @param dmEmployee
     * @return
     */
    @Override
    public List<DmEmployee> getByConditionDefaultDepartCode(DmEmployee dmEmployee) {
        String[] strings = {"departCode"};
        ConditionSelect<DmEmployee> conditionSelect = new ConditionSelect<>(dmEmployee, new QueryWrapper<>(), this.dmEmployeeMapper, strings);
        return conditionSelect.getResultBySomeLikeRight();
    }

    /**
     * 添加员工
     * @param dmEmployees
     * @return
     */
    @Override
    @Transactional(rollbackFor = Exception.class)
    public ResultBean<Integer> addEmployee(DmEmployee[] dmEmployees) {
        int i = 0;
        for (DmEmployee d : dmEmployees) {

                       this.dmEmployeeMapper.insert(d) ;
        }
        resultBean = new ResultBean<Integer>();

        return resultBean;
    }

    /**
     * 修改员工
     * @param dmEmployees
     * @return
     */
    @Override
    public ResultBean<Integer> updateEmployee(DmEmployee[] dmEmployees) {
        int i = 0;
        for (DmEmployee d : dmEmployees) {
            if(this.dmEmployeeMapper.updateById(d) == 1) i++;
//            if(d.getDepartCode() == null){
//                continue;
//            }else{
//                if(d.getDepartCode().length() == 2){
//                    if(d.getEmployeeNo().substring(0, 2).equals(d.getDepartCode())){
//                        if(this.dmEmployeeMapper.updateById(d) == 1) i++;
//                    }else{
//                        continue;
//                    }
//                }else if(d.getDepartCode().length() == 4){
//                    if(d.getEmployeeNo().substring(0, 4).equals(d.getDepartCode())){
//                        if(this.dmEmployeeMapper.updateById(d) == 1) i++;
//                    }else{
//                        continue;
//                    }
//                }else{
//                    continue;
//                }
//            }
        }
        resultBean = new ResultBean<Integer>();
        resultBean.setData(i);
        return resultBean;
    }

    /**
     * 删除员工
     * @param dmEmployees
     * @return
     */
    @Override
    public ResultBean<Integer> delEmployee(DmEmployee[] dmEmployees) {
        int i = 0;
        for (DmEmployee d : dmEmployees) {
            if(this.dmEmployeeMapper.deleteById(d) == 1) i++;
        }
        resultBean = new ResultBean<Integer>();
        resultBean.setData(i);
        return resultBean;
    }
}
